@@ -1,6 +1,6 @@
 package Net::Google::Analytics::Response;
 {
-  $Net::Google::Analytics::Response::VERSION = '2.99_02';
+  $Net::Google::Analytics::Response::VERSION = '3.00';
 }
 use strict;
 
@@ -8,9 +8,14 @@ use strict;
 
 use Class::XSAccessor
     accessors => [ qw(
-        is_success code message content
+        is_success
+        code message content
         total_results start_index items_per_page
-        _column_headers rows _totals
+        contains_sampled_data
+        profile_info
+        rows
+        _column_headers
+        _totals
     ) ],
     constructor => 'new';
 
@@ -25,6 +30,8 @@ sub _parse_json {
 
     $self->items_per_page($json->{itemsPerPage});
     $self->total_results($json->{totalResults});
+    $self->contains_sampled_data($json->{containsSampledData});
+    $self->profile_info($json->{profileInfo});
 
     my $json_totals = $json->{totalsForAllResults};
     my %totals;
@@ -163,29 +170,59 @@ Net::Google::Analytics::Response - Google Analytics API response
 
 =head1 VERSION
 
-version 2.99_02
+version 3.00
+
+=head1 SYNOPSIS
+
+    my $res = $analytics->retrieve($req);
+    die("GA error: " . $res->error_message) if !$res->is_success;
+
+    print
+        "Results: 1 - ", $res->items_per_page,
+        " of ", $res->total_results, "\n\n";
+
+    for my $row (@{ $res->rows }) {
+        print
+            $row->get_source,  ": ",
+            $row->get_visits,  " visits, ",
+            $row->get_bounces, " bounces\n";
+    }
+
+    print
+        "\nTotal: ",
+        $res->totals("visits"),  " visits, ",
+        $res->totals("bounces"), " bounces\n";
 
 =head1 DESCRIPTION
 
 Response class for L<Net::Google::Analytics> web service.
 
+=head1 CONSTRUCTOR
+
+=head2 new
+
 =head1 ACCESSORS
 
 =head2 is_success
 
-True for successful requests, false in case of an error
+True for successful requests, false in case of an error.
 
 =head2 code
 
-The HTTP status code
+The HTTP status code.
 
 =head2 message
 
-The HTTP status message
+The HTTP status message.
+
+=head2 content
+
+In case of an error, this field contains a JSON string with additional
+information about the error from the response body.
 
 =head2 error_message
 
-The full error message
+The full error message.
 
 =head2 total_results
 
@@ -198,11 +235,19 @@ The 1-based start index of the entries.
 
 =head2 items_per_page
 
-The number of rows.
+The number of rows returned.
+
+=head2 contains_sampled_data
+
+Return true if the results contain sampled data.
+
+=head2 profile_info
+
+Returns a hashref containing information about the analytics profile.
 
 =head2 rows
 
-An arrayref of result rows.
+An arrayref of result rows of type L<Net::Google::Analytics::Row>.
 
 =head2 dimensions
 
@@ -220,8 +265,9 @@ lower case with underscores.
 
     my $total = $res->totals($metric);
 
-Returns the total of all results for a metric. $metric is a metric name
-without the 'ga:' prefix and converted to lower case with underscores.
+Returns the sum of all results for a metric regardless of the actual subset
+of results returned. $metric is a metric name without the 'ga:' prefix and
+converted to lower case with underscores.
 
 =head2 project
 
@@ -244,7 +290,7 @@ categories.
     $res->project([ 'category' ], sub {
         my $row = shift;
 
-        my $page_path = $row->get_pagePath;
+        my $page_path = $row->get_page_path;
 
         return ('flowers') if $page_path =~ m{^/(tulips|roses)};
         return ('fruit')   if $page_path =~ m{^/(apples|oranges)};
